Function libui_ng_sys::uiBoxAppend
source · Expand description
Appends a control to the box.
Stretchy items expand to use the remaining space within the box. In the case of multiple stretchy items the space is shared equally.
@param b uiBox instance.
@param child Control instance to append.
@param stretchy TRUE to stretch control, FALSE otherwise.
@memberof uiBox