Function libui_ng_sys::uiEditableComboboxOnChanged
source · pub unsafe extern "C" fn uiEditableComboboxOnChanged(
c: *mut uiEditableCombobox,
f: Option<unsafe extern "C" fn(sender: *mut uiEditableCombobox, senderData: *mut c_void)>,
data: *mut c_void
)Expand description
Registers a callback for when an editable combo box item is selected or user text changed.
@param c uiEditableCombobox instance. @param f Callback function.\n @p sender Back reference to the instance that triggered the callback.\n @p senderData User data registered with the sender instance. @param data User data to be passed to the callback.
@note The callback is not triggered when calling uiEditableComboboxSetText(). @note Only one callback can be registered at a time. @memberof uiEditableCombobox