Function libui_ng_sys::uiTabDelete
source · Expand description
Removes the control at @p index.
@param t uiTab instance. @param index Index of the control to be removed. @note The control is neither destroyed nor freed. @memberof uiTab
Removes the control at @p index.
@param t uiTab instance. @param index Index of the control to be removed. @note The control is neither destroyed nor freed. @memberof uiTab